==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
var ScatterSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSplineSeriesDescriptionMetadata, _super);
    function ScatterSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSplineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSplineSeriesDescriptionMetadata.a == null) {
            ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
        }
        if (a.g(ScatterSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    ScatterSplineSeriesDescriptionMetadata.d = function (a) {
        ScatterSplineSeriesDescriptionMetadata.b(a);
        a.u("ScatterSplineSeries", function () { return new ScatterSplineSeriesDescription(); });
        a.t("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
}(Base));
export { ScatterSplineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
var ScatterSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSplineSeriesDescriptionMetadata, _super);
    function ScatterSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSplineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSplineSeriesDescriptionMetadata.a == null) {
            ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    ScatterSplineSeriesDescriptionMetadata.d = function (a) {
        ScatterSplineSeriesDescriptionMetadata.b(a);
        a.aa("ScatterSplineSeries", function () { return new ScatterSplineSeriesDescription(); });
        a.z("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
}(Base));
export { ScatterSplineSeriesDescriptionMetadata };
